@@ -42,7 +42,7 @@ static FrCommandClass *parent_class = NULL;
 
 
 static char *
-get_uncompressed_name_from_archive (FrCommand  *comm, 
+get_uncompressed_name_from_archive (FrCommand  *comm,
 				    const char *archive)
 {
 	int      fd;
@@ -52,11 +52,11 @@ get_uncompressed_name_from_archive (FrCommand  *comm,
 
 	if (! is_mime_type (comm->mime_type, "application/x-gzip"))
 		return NULL;
-	
+
 	fd = open (archive, O_RDONLY);
-	if (fd < 0) 
+	if (fd < 0)
 		return NULL;
-	
+
 	if (read (fd, &buffer, 11) < 11) {
 		close (fd);
 		return NULL;
@@ -73,7 +73,7 @@ get_uncompressed_name_from_archive (FrCommand  *comm,
 		close (fd);
 		return NULL;
 	}
-	
+
 	str = g_string_new ("");
 	/* Don't lose the first character */
 	g_string_append_c (str, buffer[10]);
@@ -87,10 +87,10 @@ get_uncompressed_name_from_archive (FrCommand  *comm,
 #endif
 			return filename;
 		}
-		
+
 		g_string_append_c (str, buffer[0]);
 	}
-	
+
 	close (fd);
 	g_string_free (str, TRUE);
 
@@ -99,7 +99,7 @@ get_uncompressed_name_from_archive (FrCommand  *comm,
 
 
 static void
-list__process_line (char     *line, 
+list__process_line (char     *line,
 		    gpointer  data)
 {
 	FrCommand  *comm = FR_COMMAND (data);
@@ -118,10 +118,10 @@ list__process_line (char     *line,
 		fdata->size = get_file_size (comm->filename);
 
 	filename = get_uncompressed_name_from_archive (comm, comm->filename);
-	if (filename == NULL) 
+	if (filename == NULL)
 		filename = remove_extension_from_path (comm->filename);
 
-	fdata->full_path = g_strconcat ("/", 
+	fdata->full_path = g_strconcat ("/",
 					file_name_from_path (filename),
 					NULL);
 	g_free (filename);
@@ -129,27 +129,26 @@ list__process_line (char     *line,
 	fdata->original_path = fdata->full_path + 1;
 	fdata->link = NULL;
 	fdata->modified = get_file_mtime_for_path (comm->filename);
-	
+
 	fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 	fdata->path = remove_level_from_path (fdata->full_path);
-	
+
 	if (*fdata->name == 0)
 		file_data_free (fdata);
-	else 
+	else
 		fr_command_add_file (comm, fdata);
 }
 
 
 static void
-fr_command_cfile_list (FrCommand  *comm,
-		       const char *password)
+fr_command_cfile_list (FrCommand  *comm)
 {
 	FrCommandCFile *comm_cfile = FR_COMMAND_CFILE (comm);
 
 	if (is_mime_type (comm->mime_type, "application/x-gzip")) {
 		/* gzip let us known the uncompressed size */
 
-		fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
+		fr_process_set_out_line_func (FR_COMMAND (comm)->process,
 					      list__process_line,
 					      comm);
 
@@ -159,10 +158,10 @@ fr_command_cfile_list (FrCommand  *comm,
 		fr_process_add_arg (comm->process, comm->filename);
 		fr_process_end_command (comm->process);
 		fr_process_start (comm->process);
-	} 
+	}
 	else {
-		/* ... other compressors do not support this feature so 
-		 * simply use the archive size, suboptimal but there is no 
+		/* ... other compressors do not support this feature so
+		 * simply use the archive size, suboptimal but there is no
 		 * alternative. */
 
 		FileData *fdata;
@@ -171,7 +170,7 @@ fr_command_cfile_list (FrCommand  *comm,
 		fdata = file_data_new ();
 
 		filename = remove_extension_from_path (comm->filename);
-		fdata->full_path = g_strconcat ("/", 
+		fdata->full_path = g_strconcat ("/",
 						file_name_from_path (filename),
 						NULL);
 		g_free (filename);
@@ -180,20 +179,20 @@ fr_command_cfile_list (FrCommand  *comm,
 		fdata->link = NULL;
 		fdata->size = get_file_size_for_path (comm->filename);
 		fdata->modified = get_file_mtime_for_path (comm->filename);
-		
+
 		fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 		fdata->path = remove_level_from_path (fdata->full_path);
-		
+
 		if (*fdata->name == 0)
 			file_data_free (fdata);
-		else 
+		else
 			fr_command_add_file (comm, fdata);
-		
+
 		comm_cfile->error.type = FR_PROC_ERROR_NONE;
 		comm_cfile->error.status = 0;
-		g_signal_emit_by_name (G_OBJECT (comm), 
+		g_signal_emit_by_name (G_OBJECT (comm),
 				       "done",
-				       comm->action, 
+				       comm->action,
 				       &comm_cfile->error);
 	}
 }
@@ -201,12 +200,11 @@ fr_command_cfile_list (FrCommand  *comm,
 
 static void
 fr_command_cfile_add (FrCommand     *comm,
+		      const char    *from_file,
 		      GList         *file_list,
 		      const char    *base_dir,
 		      gboolean       update,
-		      gboolean       recursive,
-		      const char    *password,
-		      FrCompression  compression)
+		      gboolean       recursive)
 {
 	const char *filename;
 	char       *temp_dir;
@@ -274,6 +272,13 @@ fr_command_cfile_add (FrCommand     *comm,
 		fr_process_end_command (comm->process);
 		compressed_filename = g_strconcat (filename, ".lzo", NULL);
 	}
+	else if (is_mime_type (comm->mime_type, "application/x-rzip")) {
+		fr_process_begin_command (comm->process, "rzip");
+		fr_process_set_working_dir (comm->process, temp_dir);
+		fr_process_add_arg (comm->process, filename);
+		fr_process_end_command (comm->process);
+		compressed_filename = g_strconcat (filename, ".rz", NULL);
+	}
 
       	/* copy compressed file to the dest dir */
 
@@ -301,8 +306,9 @@ fr_command_cfile_add (FrCommand     *comm,
 
 
 static void
-fr_command_cfile_delete (FrCommand *comm,
-			 GList     *file_list)
+fr_command_cfile_delete (FrCommand  *comm,
+			 const char *from_file,
+			 GList      *file_list)
 {
 	/* never called */
 }
@@ -310,12 +316,12 @@ fr_command_cfile_delete (FrCommand *comm,
 
 static void
 fr_command_cfile_extract (FrCommand  *comm,
+			  const char *from_file,
 			  GList      *file_list,
 			  const char *dest_dir,
 			  gboolean    overwrite,
 			  gboolean    skip_older,
-			  gboolean    junk_paths,
-			  const char *password)
+			  gboolean    junk_paths)
 {
 	char *temp_dir;
 	char *dest_file;
@@ -376,13 +382,20 @@ fr_command_cfile_extract (FrCommand  *comm,
 		fr_process_add_arg (comm->process, temp_file);
 		fr_process_end_command (comm->process);
 	}
+	else if (is_mime_type (comm->mime_type, "application/x-rzip")) {
+		fr_process_begin_command (comm->process, "rzip");
+		fr_process_add_arg (comm->process, "-f");
+		fr_process_add_arg (comm->process, "-d");
+		fr_process_add_arg (comm->process, temp_file);
+		fr_process_end_command (comm->process);
+	}
 
 	/* copy uncompress file to the dest dir */
 
 	uncompr_file = remove_extension_from_path (temp_file);
-        
+
 	compr_file = get_uncompressed_name_from_archive (comm, comm->filename);
-	if (compr_file == NULL) 
+	if (compr_file == NULL)
 		compr_file = remove_extension_from_path (file_name_from_path (comm->filename));
 	dest_file = g_strconcat (dest_dir,
 				 "/",
@@ -411,38 +424,61 @@ fr_command_cfile_extract (FrCommand  *comm,
 }
 
 
-static void
-fr_command_cfile_set_mime_type (FrCommand  *comm,
-			        const char *mime_type)
+const char *cfile_mime_type[] = { "application/x-gzip",
+				  "application/x-bzip",
+				  "application/x-compress",
+				  "application/x-lzma",
+				  "application/x-lzop",
+				  "application/x-rzip",
+				  NULL };
+
+
+const char **
+fr_command_cfile_get_mime_types (FrCommand *comm)
 {
-	FR_COMMAND_CLASS (parent_class)->set_mime_type (comm, mime_type);
-	
-	if (is_mime_type (comm->mime_type, "application/x-gzip")) {
-		if (is_program_in_path ("gzip"))
-			comm->capabilities |= FR_COMMAND_CAP_READ_WRITE;
-	}
-	else if (is_mime_type (comm->mime_type, "application/x-bzip")) {
-		if (is_program_in_path ("bzip2"))
-			comm->capabilities |= FR_COMMAND_CAP_READ_WRITE;
-	}
-	else if (is_mime_type (comm->mime_type, "application/x-compress")) {
-		if (is_program_in_path ("compress"))
-			comm->capabilities |= FR_COMMAND_CAP_WRITE;
-		if (is_program_in_path ("uncompress"))
-			comm->capabilities |= FR_COMMAND_CAP_READ;
-	}
-	else if (is_mime_type (comm->mime_type, "application/x-lzma")) {
-		if (is_program_in_path ("lzma"))
-			comm->capabilities |= FR_COMMAND_CAP_READ_WRITE;
-	}
-	else if (is_mime_type (comm->mime_type, "application/x-lzop")) {
-		if (is_program_in_path ("lzop"))
-			comm->capabilities |= FR_COMMAND_CAP_READ_WRITE;
-	}
+	return cfile_mime_type;
 }
 
 
-static void 
+FrCommandCap
+fr_command_cfile_get_capabilities (FrCommand  *comm,
+			           const char *mime_type)
+{
+	FrCommandCap capabilities;
+
+	capabilities = FR_COMMAND_CAN_DO_NOTHING;
+	if (is_mime_type (mime_type, "application/x-gzip")) {
+		if (is_program_in_path ("gzip"))
+			capabilities |= FR_COMMAND_CAN_READ_WRITE;
+	}
+	else if (is_mime_type (mime_type, "application/x-bzip")) {
+		if (is_program_in_path ("bzip2"))
+			capabilities |= FR_COMMAND_CAN_READ_WRITE;
+	}
+	else if (is_mime_type (mime_type, "application/x-compress")) {
+		if (is_program_in_path ("compress"))
+			capabilities |= FR_COMMAND_CAN_WRITE;
+		if (is_program_in_path ("uncompress"))
+			capabilities |= FR_COMMAND_CAN_READ;
+	}
+	else if (is_mime_type (mime_type, "application/x-lzma")) {
+		if (is_program_in_path ("lzma"))
+			capabilities |= FR_COMMAND_CAN_READ_WRITE;
+	}
+	else if (is_mime_type (mime_type, "application/x-lzop")) {
+		if (is_program_in_path ("lzop"))
+			capabilities |= FR_COMMAND_CAN_READ_WRITE;
+	}
+	else if (is_mime_type (mime_type, "application/x-rzip")) {
+		if (is_program_in_path ("rzip"))
+			capabilities |= FR_COMMAND_CAN_READ_WRITE;
+	}
+
+	return capabilities;
+}
+
+
+static void
 fr_command_cfile_finalize (GObject *object)
 {
         g_return_if_fail (object != NULL);
@@ -454,7 +490,7 @@ fr_command_cfile_finalize (GObject *object)
 }
 
 
-static void 
+static void
 fr_command_cfile_class_init (FrCommandCFileClass *class)
 {
         GObjectClass   *gobject_class = G_OBJECT_CLASS (class);
@@ -465,19 +501,20 @@ fr_command_cfile_class_init (FrCommandCFileClass *class)
 
         gobject_class->finalize = fr_command_cfile_finalize;
 
-        afc->list          = fr_command_cfile_list;
-	afc->add           = fr_command_cfile_add;
-	afc->delete        = fr_command_cfile_delete;
-	afc->extract       = fr_command_cfile_extract;
-	afc->set_mime_type = fr_command_cfile_set_mime_type;
+        afc->list             = fr_command_cfile_list;
+	afc->add              = fr_command_cfile_add;
+	afc->delete           = fr_command_cfile_delete;
+	afc->extract          = fr_command_cfile_extract;
+	afc->get_mime_types   = fr_command_cfile_get_mime_types;
+	afc->get_capabilities = fr_command_cfile_get_capabilities;
 }
 
- 
-static void 
+
+static void
 fr_command_cfile_init (FrCommand *comm)
 {
 	comm->propAddCanUpdate             = TRUE;
-	comm->propAddCanReplace            = TRUE; 
+	comm->propAddCanReplace            = TRUE;
 	comm->propExtractCanAvoidOverwrite = FALSE;
 	comm->propExtractCanSkipOlder      = FALSE;
 	comm->propExtractCanJunkPaths      = FALSE;
