@@ -42,9 +42,10 @@ struct _FrCommandRar
 {
 	FrCommand  __parent;
 
-	gboolean list_started;
-	gboolean odd_line;
+	gboolean  list_started;
+	gboolean  odd_line;
 	FileData *fdata;
+	gboolean  multi_volume;
 };
 
 struct _FrCommandRarClass
@@ -52,8 +53,6 @@ struct _FrCommandRarClass
 	FrCommandClass __parent_class;
 };
 
-GType        fr_command_rar_get_type        (void);
-FrCommand*   fr_command_rar_new             (FrProcess *process,
-					     const char *filename);
+GType fr_command_rar_get_type (void);
 
 #endif /* FR_COMMAND_RAR_H */
