@@ -127,10 +127,9 @@ process_line (char     *line,
 		else
 			size = g_ascii_strtoull (ssize, NULL, 10);
 
-		if (comm->file_list != NULL) {
-			fdata = (FileData *) comm->file_list->data;
-			fdata->size = size;
-		}
+		if (unstuff_comm->fdata != NULL)
+			unstuff_comm->fdata->size = size;
+
 		return;
 	}
 
@@ -172,7 +171,8 @@ process_line (char     *line,
 	fdata->size = 0;
 	fdata->modified = time (NULL);
 
-	comm->file_list = g_list_prepend (comm->file_list, fdata);
+	unstuff_comm->fdata = fdata;
+	fr_command_add_file (comm, fdata);
 
 	unlink (real_filename);
 	g_free (real_filename);
@@ -180,8 +180,7 @@ process_line (char     *line,
 
 
 static void
-fr_command_unstuff_list (FrCommand  *comm,
-			 const char *password)
+fr_command_unstuff_list (FrCommand  *comm)
 {
 	char *arg, *path;
 	char *filename;
@@ -204,7 +203,7 @@ fr_command_unstuff_list (FrCommand  *comm,
 	fr_process_add_arg (comm->process, arg);
 	g_free (arg);
 
-	filename = unstuff_is_shit_with_filenames (comm->e_filename);
+	filename = unstuff_is_shit_with_filenames (comm->filename);
 	fr_process_add_arg (comm->process, filename);
 	g_free (filename);
 	fr_process_end_command (comm->process);
@@ -214,12 +213,12 @@ fr_command_unstuff_list (FrCommand  *comm,
 
 static void
 fr_command_unstuff_extract (FrCommand  *comm,
+			    const char  *from_file,
 			    GList      *file_list,
 			    const char *dest_dir,
 			    gboolean    overwrite,
 			    gboolean    skip_older,
-			    gboolean    junk_paths,
-			    const char *password)
+			    gboolean    junk_paths)
 {
 #if 0
 	GList *scan;
@@ -229,20 +228,21 @@ fr_command_unstuff_extract (FrCommand  *comm,
 	fr_process_begin_command (comm->process, "unstuff");
 
 	if (dest_dir != NULL) {
-		char *e_dest_dir = fr_command_escape (comm, dest_dir);
-		char *e_dest_dir_dots = unstuff_is_shit_with_filenames (e_dest_dir);
-		char *arg = g_strdup_printf ("-d=%s", e_dest_dir_dots);
+		char *dest_dir_dots;
+		char *arg;
+
+		dest_dir_dots = unstuff_is_shit_with_filenames (dest_dir);
+		arg = g_strdup_printf ("-d=%s", dest_dir_dots);
 		fr_process_add_arg (comm->process, arg);
 		FR_COMMAND_UNSTUFF (comm)->target_dir = NULL;
 		g_free (arg);
-		g_free (e_dest_dir);
-		g_free (e_dest_dir_dots);
+		g_free (dest_dir_dots);
 	}
 
 	fr_process_add_arg (comm->process, "--trace");
 
 	/* unstuff doesn't like file paths starting with /, that's so shite */
-	filename = unstuff_is_shit_with_filenames (comm->e_filename);
+	filename = unstuff_is_shit_with_filenames (comm->filename);
 	fr_process_add_arg (comm->process, filename);
 	g_free (filename);
 
@@ -258,7 +258,7 @@ fr_command_unstuff_extract (FrCommand  *comm,
 
 static void
 fr_command_unstuff_handle_error (FrCommand   *comm,
-			     FRProcError *error)
+				 FrProcError *error)
 {
 	if ((error->type == FR_PROC_ERROR_COMMAND_ERROR)
 	    && (error->status <= 1))
@@ -266,6 +266,30 @@ fr_command_unstuff_handle_error (FrCommand   *comm,
 }
 
 
+const char *unstuff_mime_type[] = { "application/x-stuffit", NULL };
+
+
+const char **
+fr_command_unstuff_get_mime_types (FrCommand *comm)
+{
+	return unstuff_mime_type;
+}
+
+
+FrCommandCap
+fr_command_unstuff_get_capabilities (FrCommand  *comm,
+			             const char *mime_type)
+{
+	FrCommandCap capabilities;
+
+	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES;
+	if (is_program_in_path ("unstuff"))
+		capabilities |= FR_COMMAND_CAN_READ;
+
+	return capabilities;
+}
+
+
 static void
 fr_command_unstuff_class_init (FrCommandUnstuffClass *class)
 {
@@ -277,20 +301,19 @@ fr_command_unstuff_class_init (FrCommandUnstuffClass *class)
 
 	gobject_class->finalize = fr_command_unstuff_finalize;
 
-	afc->list         = fr_command_unstuff_list;
-	afc->add          = NULL;
-	afc->delete       = NULL;
-	afc->extract      = fr_command_unstuff_extract;
-	afc->handle_error = fr_command_unstuff_handle_error;
+	afc->list             = fr_command_unstuff_list;
+	afc->add              = NULL;
+	afc->delete           = NULL;
+	afc->extract          = fr_command_unstuff_extract;
+	afc->handle_error     = fr_command_unstuff_handle_error;
+	afc->get_mime_types   = fr_command_unstuff_get_mime_types;
+	afc->get_capabilities = fr_command_unstuff_get_capabilities;
 }
 
 
 static void
 fr_command_unstuff_init (FrCommand *comm)
 {
-	comm->file_type = FR_FILE_TYPE_STUFFIT;
-
-	comm->propCanModify                = FALSE;
 	comm->propAddCanUpdate             = FALSE;
 	comm->propAddCanReplace            = FALSE;
 	comm->propExtractCanAvoidOverwrite = FALSE;
@@ -345,20 +368,3 @@ fr_command_unstuff_get_type ()
 
 	return type;
 }
-
-
-FrCommand *
-fr_command_unstuff_new (FrProcess  *process,
-		    const char *filename)
-{
-	FrCommand *comm;
-
-	if (!is_program_in_path("unstuff")) {
-		return NULL;
-	}
-
-	comm = FR_COMMAND (g_object_new (FR_TYPE_COMMAND_UNSTUFF, NULL));
-	fr_command_construct (comm, process, filename);
-
-	return comm;
-}
