@@ -173,8 +173,7 @@ add_password_arg (FrCommand  *comm,
 
 
 static void
-fr_command_zip_list (FrCommand  *comm,
-		     const char *password)
+fr_command_zip_list (FrCommand  *comm)
 {
 	FR_COMMAND_ZIP (comm)->is_empty = FALSE;
 
@@ -210,12 +209,11 @@ process_line__common (char     *line,
 
 static void
 fr_command_zip_add (FrCommand     *comm,
+		    const char    *from_file,
 		    GList         *file_list,
 		    const char    *base_dir,
 		    gboolean       update,
-		    gboolean       recursive,
-		    const char    *password,
-		    FrCompression  compression)
+		    gboolean       recursive)
 {
 	GList *scan;
 
@@ -234,9 +232,9 @@ fr_command_zip_add (FrCommand     *comm,
 	if (update)
 		fr_process_add_arg (comm->process, "-u");
 
-	add_password_arg (comm, password);
+	add_password_arg (comm, comm->password);
 
-	switch (compression) {
+	switch (comm->compression) {
 	case FR_COMPRESSION_VERY_FAST:
 		fr_process_add_arg (comm->process, "-1"); break;
 	case FR_COMPRESSION_FAST:
@@ -248,8 +246,7 @@ fr_command_zip_add (FrCommand     *comm,
 	}
 
 	fr_process_add_arg (comm->process, comm->filename);
-
-	for (scan = file_list; scan; scan = scan->next) 
+	for (scan = file_list; scan; scan = scan->next)
 		fr_process_add_arg (comm->process, scan->data);
 
 	fr_process_end_command (comm->process);
@@ -257,8 +254,9 @@ fr_command_zip_add (FrCommand     *comm,
 
 
 static void
-fr_command_zip_delete (FrCommand *comm,
-		       GList     *file_list)
+fr_command_zip_delete (FrCommand  *comm,
+		       const char *from_file,
+		       GList      *file_list)
 {
 	GList *scan;
 
@@ -268,9 +266,9 @@ fr_command_zip_delete (FrCommand *comm,
 
 	fr_process_begin_command (comm->process, "zip");
 	fr_process_add_arg (comm->process, "-d");
-	fr_process_add_arg (comm->process, comm->filename);
 
-	for (scan = file_list; scan; scan = scan->next) 
+	fr_process_add_arg (comm->process, comm->filename);
+	for (scan = file_list; scan; scan = scan->next)
 		fr_process_add_arg (comm->process, scan->data);
 
 	fr_process_end_command (comm->process);
@@ -279,12 +277,12 @@ fr_command_zip_delete (FrCommand *comm,
 
 static void
 fr_command_zip_extract (FrCommand  *comm,
+			const char *from_file,
 			GList      *file_list,
 			const char *dest_dir,
 			gboolean    overwrite,
 			gboolean    skip_older,
-			gboolean    junk_paths,
-			const char *password)
+			gboolean    junk_paths)
 {
 	GList *scan;
 
@@ -306,10 +304,10 @@ fr_command_zip_extract (FrCommand  *comm,
 		fr_process_add_arg (comm->process, "-u");
 	if (junk_paths)
 		fr_process_add_arg (comm->process, "-j");
-	add_password_arg (comm, password);
-	fr_process_add_arg (comm->process, comm->filename);
+	add_password_arg (comm, comm->password);
 
-	for (scan = file_list; scan; scan = scan->next) 
+	fr_process_add_arg (comm->process, comm->filename);
+	for (scan = file_list; scan; scan = scan->next)
 		fr_process_add_arg (comm->process, scan->data);
 
 	fr_process_end_command (comm->process);
@@ -317,12 +315,11 @@ fr_command_zip_extract (FrCommand  *comm,
 
 
 static void
-fr_command_zip_test (FrCommand   *comm,
-		     const char  *password)
+fr_command_zip_test (FrCommand   *comm)
 {
 	fr_process_begin_command (comm->process, "unzip");
 	fr_process_add_arg (comm->process, "-t");
-	add_password_arg (comm, password);
+	add_password_arg (comm, comm->password);
 	fr_process_add_arg (comm->process, comm->filename);
 	fr_process_end_command (comm->process);
 }
@@ -340,15 +337,15 @@ fr_command_zip_handle_error (FrCommand   *comm,
 		else {
 			GList *output;
 			GList *scan;
-			
+
 			if (comm->action == FR_ACTION_TESTING_ARCHIVE)
 				output = comm->process->out.raw;
 			else
 				output = comm->process->err.raw;
-			
+
 			for (scan = g_list_last (output); scan; scan = scan->prev) {
 				char *line = scan->data;
-				
+
 				if (strstr (line, "incorrect password") != NULL) {
 					error->type = FR_PROC_ERROR_ASK_PASSWORD;
 					break;
@@ -359,21 +356,36 @@ fr_command_zip_handle_error (FrCommand   *comm,
 }
 
 
-static void
-fr_command_zip_set_mime_type (FrCommand  *comm,
-			      const char *mime_type)
+const char *zip_mime_type[] = { "application/x-cbz",
+				"application/x-executable",
+				"application/zip",
+				NULL };
+
+
+const char **
+fr_command_zip_get_mime_types (FrCommand *comm)
 {
-	FR_COMMAND_CLASS (parent_class)->set_mime_type (comm, mime_type);
-	
-	comm->capabilities |= FR_COMMAND_CAP_ARCHIVE_MANY_FILES;
+	return zip_mime_type;
+}
+
+
+FrCommandCap
+fr_command_zip_get_capabilities (FrCommand  *comm,
+			         const char *mime_type)
+{
+	FrCommandCap capabilities;
+
+	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES | FR_COMMAND_CAN_ENCRYPT;
 	if (is_program_in_path ("zip")) {
-		if (strcmp (comm->mime_type, "application/x-ms-dos-executable") == 0)
-			comm->capabilities |= FR_COMMAND_CAP_READ;
+		if (strcmp (mime_type, "application/x-executable") == 0)
+			capabilities |= FR_COMMAND_CAN_READ;
 		else
-			comm->capabilities |= FR_COMMAND_CAP_ALL;
-	} 
-	else if (is_program_in_path ("unzip")) 
-		comm->capabilities |= FR_COMMAND_CAP_READ;
+			capabilities |= FR_COMMAND_CAN_READ_WRITE;
+	}
+	else if (is_program_in_path ("unzip"))
+		capabilities |= FR_COMMAND_CAN_READ;
+
+	return capabilities;
 }
 
 
@@ -388,13 +400,14 @@ fr_command_zip_class_init (FrCommandZipClass *class)
 
 	gobject_class->finalize = fr_command_zip_finalize;
 
-	afc->list           = fr_command_zip_list;
-	afc->add            = fr_command_zip_add;
-	afc->delete         = fr_command_zip_delete;
-	afc->extract        = fr_command_zip_extract;
-	afc->test           = fr_command_zip_test;
-	afc->handle_error   = fr_command_zip_handle_error;
-	afc->set_mime_type  = fr_command_zip_set_mime_type;
+	afc->list             = fr_command_zip_list;
+	afc->add              = fr_command_zip_add;
+	afc->delete           = fr_command_zip_delete;
+	afc->extract          = fr_command_zip_extract;
+	afc->test             = fr_command_zip_test;
+	afc->handle_error     = fr_command_zip_handle_error;
+	afc->get_mime_types   = fr_command_zip_get_mime_types;
+	afc->get_capabilities = fr_command_zip_get_capabilities;
 }
 
 
